Learn R Programming

chillR (version 0.62)

runn_mean: Running mean of a vector

Description

Function to calculate the running mean of a numeric vector

Usage

runn_mean(vec, runn_mean)

Arguments

vec
numeric vector
runn_mean
number of vector elements to use for calculating the running mean

Value

numeric vector containing the running mean

Examples

Run this code


plot(runn_mean(rnorm(1000),150))

Run the code above in your browser using DataLab